#ifndef NT2_INCLUDE_FUNCTIONS_REPEAT_UPPER_HALF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REPEAT_UPPER_HALF_HPP_INCLUDED

#include <nt2/swar/include/functions/repeat_upper_half.hpp>

#endif
